# DJALLIN2

A mildly configurable twitch noisemaker capable of responding to chat and point redemptions.

Available through pip (`djallin2`) or as a [standalone executable](https://github.com/vilhelmen/djallin2/releases) for macOS and Windows.


## Configuration

`config.txt` holds your token and configures chat and point responders.
Take a look at the [example configuration](./example_config.txt) for an explanation of how it works.


# TODO:
1. This
1. HTTP command receiver (lioran)
1. custom hook code - lioran example? obs websocket?
1. more flexible command triggers (regex??)
1. Bits?
1. Does linux support audio these days?
